<?php
/**
* @package Simple-FB-Likebox
* @version 2.1
*/
/*
Plugin Name: Simple-FB-Likebox
Plugin URI: https://tips4life.me/Simple-FB-Likebox
Description: Wordpressで記事下へ「オシャレなFacebookのいいねボックス」を簡単に表示できるプラグインです。
Version: 2.1
Author: RA’s
Author URI: https://tips4life.me/profile
License: GPLv2
*/

wp_enqueue_style('sfl', plugins_url('css/style.css', __FILE__));

function add_sflStyle_to_head() {
	if(has_post_thumbnail()) {
		$thumbnail = get_the_post_thumbnail_url(get_the_ID());
		echo '<style type="text/css">.sfl_thumbnail {background-image: url(' .$thumbnail .') ;}</style>';
	} else {
		echo '<style type="text/css">.sfl_thumbnail{display:flex;justify-content:center;-ms-align-items:center;align-items:center;padding:0 .5em;background:lightslategray;text-align:center;font-size:1.6em;color:white;line-height:1.7;}</style>';
	}
}
add_action( 'wp_head', 'add_sflStyle_to_head' );

//AMP
function sfl_callBack($sfl_buffer) {
	if(is_single()) {
		$ampFbSpt = '<script async custom-element="amp-facebook-like" src="https://cdn.ampproject.org/v0/amp-facebook-like-0.1.js"></script>';
		if(has_post_thumbnail()) {
			$ampThumb = get_the_post_thumbnail_url(get_the_ID());
			$ampFbCss = '.sfl_thumbnail {background-image: url(' .$ampThumb .') ;}';
		} else {
			$ampFbCss = '.sfl_thumbnail{display:flex;justify-content:center;-ms-align-items:center;align-items:center;padding:0 .5em;background:lightslategray;text-align:center;font-size:1.6em;color:white;line-height:1.7;}';
		}
		$sfl_css = file_get_contents(plugins_url().'/simple-fb-likebox/css/style.php');
		$sfl_buffer = str_replace('<style amp-custom>', $ampFbSpt.'<style amp-custom>'.$ampFbCss.$sfl_css, $sfl_buffer);
	}
	return $sfl_buffer;
}
function sfl_bufStart() { ob_start("sfl_callBack"); }
function sfl_bufEnd() { ob_end_flush(); }
add_action('after_setup_theme', 'sfl_bufStart');
add_action('shutdown', 'sfl_bufEnd');

function sfl_init_option(){
	//初期化の処理を行う
	if(!get_option('sfl_installed')){
		add_option('sfl_installed', 1);
		add_option('sfl_comment', '');
		add_option('sfl_comment_n', '');
		add_option('sfl_fbpg', '');
		add_option('sfl_like_post', '');
		add_option('sfl_txt_1', '');
		add_option('sfl_txt_2', '');
	}
}
register_activation_hook(__FILE__, 'sfl_init_option');

//管理画面にメニューを追加
function add_admin_sfl() {
	add_menu_page('Simple-FB-Likebox', 'Simple-FB-Likebox', 'level_8', __FILE__, 'adminMenu_sfl', 'dashicons-upload',80);
}

function adminMenu_sfl(){
	if ($_POST['posted'] == 'sfl_save') {
		//設定画面で入力された設定値を保存
		update_option('sfl_fbpg', $_POST['sfl_fbpg']);
		$sfl_like_post = isset($_POST['sfl_like_post']) ? 1 : 0;
		update_option('sfl_like_post', $_POST['sfl_like_post']);
		update_option('sfl_comment', $_POST['sfl_comment']);
		$sfl_comment_n = isset($_POST['sfl_comment_n']) ? 1 : 0;
		update_option('sfl_comment_n', $_POST['sfl_comment_n']);
		update_option('sfl_txt_1', $_POST['sfl_txt_1']);
		update_option('sfl_txt_2', $_POST['sfl_txt_2']);
		echo '<div class="updated"><p><strong>設定を保存しました</strong></p></div>';
	}
?>
<div class="sflAdminWrap">
	<h2>「Simple-FB-Likebox」の設定</h2>
	<p>「リンク先」、「タイトルシェアコメント」、「いいね&nbsp;!&nbsp;ボタン上のテキスト」などを設定します。</p>
	<p>&emsp;※「記事をいいね！」にチェックが入ってる場合は「記事をいいね！」が優先されます。</p>
	<form method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
		<table class="form-table">
			<tr>
				<th rowspan="2"><label>Facebookページをいいね！</label></th>
				<td><p>いいね！のリンク先を「Facebookページ」に設定する場合は以下の「FacebookページのURL」を入力して下さい。<br>
					※リンク先をFacebookページにする場合は次の「記事をいいね！」のチェックを外して下さい。</p></td>
			</tr>
			<tr>
				<td><input type="text" name="sfl_fbpg" value="<?php echo get_option('sfl_fbpg'); ?>" placeholder="FacebookページのURL" /></td></tr>
			<tr>
				<th scope="row"><label>記事をいいね！</label></th>
				<td><label><input type="checkbox" name="sfl_like_post" value="1" <?php checked(get_option('sfl_like_post'), 1); ?>>&emsp;Facebookページではなく「記事をいいね！」してもらいたい場合はこちらをチェックして下さい。<p>
				※Facebookページを持っていない方はこちらをチェックします。</p></label></td>
			</tr>
			<tr>
				<th scope="row"><label>シェアコメント</label></th>
				<td><input type="text" name="sfl_comment" value="<?php echo get_option('sfl_comment'); ?>" placeholder="ぽちっとお願いします☆" /></td>
			</tr>
			<tr>
				<th scope="row"><label for="sfl_comment_n">シェアコメントの非表示</label></th>
				<td><label><input name="sfl_comment_n" type="checkbox" value="dis-n" <?php checked( 'dis-n', get_option('sfl_comment_n')); ?> /> シェアコメントが不要の方はチェックを入れて下さい。</label></td>
			</tr>
			<tr>
				<th scope="row"><label>いいね&nbsp;!&nbsp;ボタン上のテキスト&nbsp;1&nbsp;</label></th>
				<td><input type="text" name="sfl_txt_1" value="<?php echo get_option('sfl_txt_1'); ?>" placeholder="この記事が気に入ったら" /></td>
			</tr>
			<tr>
				<th scope="row"><label>いいね&nbsp;!&nbsp;ボタン上のテキスト&nbsp;2&nbsp;</label></th>
				<td><input type="text" name="sfl_txt_2" value="<?php echo get_option('sfl_txt_2'); ?>" placeholder="いいね&nbsp;!&nbsp;しよう" /></td>
			</tr>
		</table>
		<input type="hidden" name="posted" value="sfl_save">
		<?php submit_button(); ?>
	</form>
</div>
<?php
}
// 管理メニューに追加するフック
add_action('admin_menu', 'add_admin_sfl');

function is_sfl_amp(){
	$is_sfl_amp = false;
	if ( empty($_GET['amp']) ) {
		return false;
	}
	if($_GET['amp'] === '1') {
		$is_sfl_amp = true;
	}
	return $is_sfl_amp;
}

function add_post_content($content) {
	if(is_single()){
		$sfl_comment_value = get_option('sfl_comment');
		$sfl_comment_none = get_option('sfl_comment_n');
		$sfl_post_url = get_permalink();
		if(!has_post_thumbnail()) {
			$sfl_post_title = '<p>' .get_the_title(). '</p>';
		}
		$sfl_like_post_check = get_option('sfl_like_post');
		if($sfl_like_post_check == 1){
			$sfl_fbLink_value = $sfl_post_url;
		} else {
			$sfl_fbLink_value = get_option('sfl_fbpg');
		}
		$sfl_txt_1_value = get_option('sfl_txt_1');
		$sfl_txt_2_value = get_option('sfl_txt_2');
		if( is_sfl_amp() ) {
			$content .= '
	<div class="sflParent">
		<div class="shareTtl '.$sfl_comment_none.'">'.$sfl_comment_value.'</div>
		<div class="sflMain">
			<div class="sfl_thumbnail">' .$sfl_post_title. '</div>
			<div class="sflInner">
				<p class="sflTxt">'.$sfl_txt_1_value.'<br>'.$sfl_txt_2_value.'</p>
				<div><amp-facebook-like width=75 height=30 layout="fixed" data-layout="button" data-size="large" data-href="'.$sfl_fbLink_value.'"></amp-facebook-like></div>
			</div>
		</div>
	</div>
';
		} else {
		$content .= '
	<div class="sflParent">
		<div class="shareTtl '.$sfl_comment_none.'">'.$sfl_comment_value.'</div>
		<div class="sflMain">
			<div class="sfl_thumbnail">' .$sfl_post_title. '</div>
			<div class="sflInner">
				<p class="sflTxt">'.$sfl_txt_1_value.'<br>'.$sfl_txt_2_value.'</p>
				<div class="fb-like" data-href="'.$sfl_fbLink_value.'" data-layout="button" data-action="like" data-size="large" data-show-faces="true" data-share="false"></div>
			</div>
		</div>
	</div>
';
		}
	}
	return $content;
}
add_filter('the_content', 'add_post_content');

function fbRootScript ($the_content) {
	$fbScript = <<< EOF
<div id="fb-root"></div>
<script>(function(d, s, id) {
  var js, fjs = d.getElementsByTagName(s)[0];
  if (d.getElementById(id)) return;
  js = d.createElement(s); js.id = id;
  js.src = 'https://connect.facebook.net/ja_JP/sdk.js#xfbml=1&version=v2.12';
  fjs.parentNode.insertBefore(js, fjs);
}(document, 'script', 'facebook-jssdk'));</script>
EOF;
	$fbRootElm = '<div id="fb-root';
	if(strpos($the_content, $fbRootElm) === false){
		$the_content = $fbScript.$the_content;
	}
	return $the_content;
}
add_filter('the_content', 'fbRootScript');
